@@ -39,11 +39,6 @@ def category_title(obj):
         )
 
 
-@indexer(IEvent)
-def title_fr(obj):
-    return obj.title
-
-
 @indexer(IEvent)
 def title_nl(obj):
     if not obj.title_nl:
@@ -65,6 +60,27 @@ def title_en(obj):
     return obj.title_en
 
 
+@indexer(IEvent)
+def description_nl(obj):
+    if not obj.description_nl:
+        raise AttributeError
+    return obj.description_nl
+
+
+@indexer(IEvent)
+def description_de(obj):
+    if not obj.description_de:
+        raise AttributeError
+    return obj.description_de
+
+
+@indexer(IEvent)
+def description_en(obj):
+    if not obj.description_en:
+        raise AttributeError
+    return obj.description_en
+
+
 @indexer(IEvent)
 def category_and_topics_indexer(obj):
     values = []
@@ -106,22 +122,26 @@ def event_dates(obj):
     return tuple(event_days)
 
 
-@indexer(IEvent)
-def SearchableText_event(obj):
-    text = ""
-    textvalue = IRichText(obj).text
-    if IRichTextValue.providedBy(textvalue):
-        transforms = api.portal.get_tool("portal_transforms")
-        raw = safe_unicode(textvalue.raw)
-        text = (
-            transforms.convertTo(
-                "text/plain",
-                raw,
-                mimetype=textvalue.mimeType,
+def get_searchable_text(obj, lang):
+    def get_text(lang):
+        text = ""
+        if lang == "fr":
+            textvalue = IRichText(obj).text
+        else:
+            textvalue = getattr(IRichText(obj), f"text_{lang}")
+        if IRichTextValue.providedBy(textvalue):
+            transforms = api.portal.get_tool("portal_transforms")
+            raw = safe_unicode(textvalue.raw)
+            text = (
+                transforms.convertTo(
+                    "text/plain",
+                    raw,
+                    mimetype=textvalue.mimeType,
+                )
+                .getData()
+                .strip()
             )
-            .getData()
-            .strip()
-        )
+        return text
 
     topics = []
     for topic in getattr(obj.aq_base, "topics", []) or []:
@@ -134,23 +154,40 @@ def SearchableText_event(obj):
         getattr(obj.aq_base, "category", None),
     )
     subjects = obj.Subject()
+    title_field_name = "title"
+    description_field_name = "description"
+    if lang != "fr":
+        title_field_name = f"{title_field_name}_{lang}"
+        description_field_name = f"{description_field_name}_{lang}"
+
     result = " ".join(
         (
-            safe_unicode(obj.title) or "",
-            safe_unicode(obj.description) or "",
-            safe_unicode(text),
-            safe_unicode(obj.title_nl) or "",
-            safe_unicode(obj.description_nl) or "",
-            safe_unicode(obj.text_nl) or "",
-            safe_unicode(obj.title_de) or "",
-            safe_unicode(obj.description_de) or "",
-            safe_unicode(obj.text_de) or "",
-            safe_unicode(obj.title_en) or "",
-            safe_unicode(obj.description_en) or "",
-            safe_unicode(obj.text_en) or "",
+            safe_unicode(getattr(obj, title_field_name)) or "",
+            safe_unicode(getattr(obj, description_field_name)) or "",
+            safe_unicode(get_text(lang)) or "",
             *topics,
             *subjects,
             safe_unicode(category),
         )
     )
     return _unicode_save_string_concat(result)
+
+
+@indexer(IEvent)
+def SearchableText_fr_event(obj):
+    return get_searchable_text(obj, "fr")
+
+
+@indexer(IEvent)
+def SearchableText_nl_event(obj):
+    return get_searchable_text(obj, "nl")
+
+
+@indexer(IEvent)
+def SearchableText_de_event(obj):
+    return get_searchable_text(obj, "de")
+
+
+@indexer(IEvent)
+def SearchableText_en_event(obj):
+    return get_searchable_text(obj, "en")
